# Beyond l10n

## Other tools

+ [babel](https://babel.pocoo.org/en/latest/) is a tool similar to l10n. It's more low-level but supports HTML and JS files.
+ [weblate](https://github.com/WeblateOrg/weblate) is a WebUI for continious translation.
+ [translate](https://github.com/translate/translate) is a CLI tool for different operations on po and mo files, like converting in different formats or showing statistics.
+ [polib](https://github.com/izimobil/polib) is a pure Python tool to work with po files. In case you want to collect some information that isn't covered by tools provided by `translate`.
+ [i18next](https://github.com/i18next/i18next) is a JS library for translating frontend.

## Further reading

+ [GNU gettext utilities](https://www.gnu.org/software/gettext/manual/html_node/index.html) is where it all started. They have alot of guides on the format of PO files and the tools you can use to work with them.
+ [linguistics.stackexchange.com](https://linguistics.stackexchange.com/) is like StackOverflow but for questions about natural languages.
